@@ -36,6 +36,10 @@ use crate::{
 pub struct Documentation(String);
 
 impl Documentation {
+    pub fn new(s: String) -> Self {
+        Documentation(s)
+    }
+
     pub fn as_str(&self) -> &str {
         &self.0
     }
@@ -102,7 +106,9 @@ impl RawAttrs {
     ) -> Self {
         let entries = collect_attrs(owner)
             .flat_map(|(id, attr)| match attr {
-                Either::Left(attr) => Attr::from_src(db, attr, hygiene, id),
+                Either::Left(attr) => {
+                    attr.meta().and_then(|meta| Attr::from_src(db, meta, hygiene, id))
+                }
                 Either::Right(comment) => comment.doc_comment().map(|doc| Attr {
                     id,
                     input: Some(Interned::new(AttrInput::Literal(SmolStr::new(doc)))),
@@ -168,10 +174,9 @@ impl RawAttrs {
                 let index = attr.id;
                 let attrs = parts.filter(|a| !a.is_empty()).filter_map(|attr| {
                     let tree = Subtree { delimiter: None, token_trees: attr.to_vec() };
-                    let attr = ast::Attr::parse(&format!("#[{}]", tree)).ok()?;
                     // FIXME hygiene
                     let hygiene = Hygiene::new_unhygienic();
-                    Attr::from_src(db, attr, &hygiene, index)
+                    Attr::from_tt(db, &tree, &hygiene, index)
                 });
 
                 let cfg_options = &crate_graph[krate].cfg_options;
@@ -578,13 +583,13 @@ impl AttrSourceMap {
                 .get(id.ast_index as usize)
                 .unwrap_or_else(|| panic!("cannot find doc comment at index {:?}", id))
                 .clone()
-                .map(|attr| Either::Right(attr))
+                .map(Either::Right)
         } else {
             self.attrs
                 .get(id.ast_index as usize)
                 .unwrap_or_else(|| panic!("cannot find `Attr` at index {:?}", id))
                 .clone()
-                .map(|attr| Either::Left(attr))
+                .map(Either::Left)
         }
     }
 }
@@ -601,7 +606,7 @@ pub struct DocsRangeMap {
 impl DocsRangeMap {
     pub fn map(&self, range: TextRange) -> Option<InFile<TextRange>> {
         let found = self.mapping.binary_search_by(|(probe, ..)| probe.ordering(range)).ok()?;
-        let (line_docs_range, idx, original_line_src_range) = self.mapping[found].clone();
+        let (line_docs_range, idx, original_line_src_range) = self.mapping[found];
         if !line_docs_range.contains_range(range) {
             return None;
         }
@@ -660,7 +665,7 @@ impl fmt::Display for AttrInput {
 impl Attr {
     fn from_src(
         db: &dyn DefDatabase,
-        ast: ast::Attr,
+        ast: ast::Meta,
         hygiene: &Hygiene,
         id: AttrId,
     ) -> Option<Attr> {
@@ -679,6 +684,19 @@ impl Attr {
         Some(Attr { id, path, input })
     }
 
+    fn from_tt(
+        db: &dyn DefDatabase,
+        tt: &tt::Subtree,
+        hygiene: &Hygiene,
+        id: AttrId,
+    ) -> Option<Attr> {
+        let (parse, _) =
+            mbe::token_tree_to_syntax_node(tt, hir_expand::FragmentKind::MetaItem).ok()?;
+        let ast = ast::Meta::cast(parse.syntax_node())?;
+
+        Self::from_src(db, ast, hygiene, id)
+    }
+
     /// Parses this attribute as a `#[derive]`, returns an iterator that yields all contained paths
     /// to derive macros.
     ///
